import React, { useState, useEffect } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import Sidebar from '../sidebar/Sidebar';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronLeft } from '@fortawesome/free-solid-svg-icons';
import axiosInstance from '../../api/axiosConfig';

const AddEmployee = () => {
  const navigate = useNavigate();
  const [employeeData, setEmployeeData] = useState({
    firstname: '',
    lastname: '',
    age: '',
    gender: '',
    email: '',
    address_line_1: '',
    address_line_2: '',
    nearby_landmark: '',
    pincode: '',
    city_id: '',
    mobile: '',
    image: null,
  });
  const [cities, setCities] = useState([]);
  const [imagePreview, setImagePreview] = useState(null);

  // Uncomment to fetch cities data from backend
  // useEffect(() => {
  //   const fetchCities = async () => {
  //     try {
  //       const response = await axiosInstance.get('/cities');
  //       if (Array.isArray(response.data)) {
  //         setCities(response.data);
  //       } else {
  //         console.error('Error: Data is not an array', response.data);
  //       }
  //     } catch (error) {
  //       console.error('Error fetching cities:', error.response || error.message);
  //     }
  //   };

  //   fetchCities();
  // }, []);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setEmployeeData({
      ...employeeData,
      [name]: value,
    });
  };

  const handleImageChange = (e) => {
    const file = e.target.files[0];
    if (file) {
      setEmployeeData({
        ...employeeData,
        image: file,
      });
      setImagePreview(URL.createObjectURL(file));
    }
  };

  const handleAddEmployeeSubmit = async (e) => {
    e.preventDefault();
    const formData = new FormData();
    Object.keys(employeeData).forEach((key) => {
      formData.append(key, employeeData[key]);
    });

    try {
      await axiosInstance.post('http://localhost:5000/employees', formData, {
        headers: {
          'Content-Type': 'multipart/form-data',
        },
      });
      navigate('/employees');
    } catch (error) {
      console.error('Error adding employee:', error.response || error.message);
    }
  };

  return (
    <div className="flex flex-row">
      <Sidebar />
      <div className="w-full flex flex-col min-h-screen text-black">
        <div className="min-h-screen text-gray-800 p-6">
          <div className="flex items-center mb-6">
            <Link to="/employees" className="text-#0e355b text-xl mr-4">
              <FontAwesomeIcon icon={faChevronLeft} />
            </Link>
            <h1 className="text-2xl font-semibold text-#0e355b">
              create employee account
            </h1>
          </div>
          <div className="flex justify-center">
            <div className="space-y-6 w-full max-w-4xl">
              <div className="text-center">
                <div className="inline-block relative">
                  <div className="bg-gray-300 w-24 h-24 rounded-full mx-auto overflow-hidden">
                    {imagePreview ? (
                      <img
                        src={imagePreview}
                        alt="Employee"
                        className="w-full h-full object-cover"
                      />
                    ) : (
                      <div className="w-full h-full flex items-center justify-center text-gray-500">
                        No image
                      </div>
                    )}
                  </div>
                  <input
                    type="file"
                    accept="image/*"
                    className="hidden"
                    id="imageUpload"
                    onChange={handleImageChange}
                  />
                  <button
                    type="button"
                    onClick={() => document.getElementById('imageUpload').click()}
                    className="absolute bottom-0 left-1/2 transform -translate-x-1/2 bg-gray-700 text-white text-xs px-2 py-1 rounded-full"
                  >
                    add customer image
                  </button>
                </div>
              </div>
              <form onSubmit={handleAddEmployeeSubmit} className="space-y-4">
                <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                  <div>
                    <label className="block text-gray-800 font-medium">
                      employee firstname:
                    </label>
                    <input
                      type="text"
                      name="firstname"
                      value={employeeData.firstname}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    />
                  </div>
                  <div>
                    <label className="block text-gray-800 font-medium">
                      employee lastname:
                    </label>
                    <input
                      type="text"
                      name="lastname"
                      value={employeeData.lastname}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    />
                  </div>
                  <div>
                    <label className="block text-gray-800 font-medium">
                      age:
                    </label>
                    <input
                      type="number"
                      name="age"
                      value={employeeData.age}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    />
                  </div>
                  <div>
                    <label className="block text-gray-800 font-medium">
                      gender:
                    </label>
                    <select
                      name="gender"
                      value={employeeData.gender}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    >
                      <option value="" disabled>
                        select gender
                      </option>
                      <option value="male">male</option>
                      <option value="female">female</option>
                      <option value="other">other</option>
                    </select>
                  </div>
                  <div>
                    <label className="block text-gray-800 font-medium">
                      mobile:
                    </label>
                    <input
                      type="text"
                      name="mobile"
                      value={employeeData.mobile}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    />
                  </div>
                  <div className="md:col-span-2 lg:col-span-3">
                    <label className="block text-gray-800 font-medium">
                      address line 1:
                    </label>
                    <input
                      type="text"
                      name="address_line_1"
                      value={employeeData.address_line_1}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    />
                  </div>
                  <div className="md:col-span-2 lg:col-span-3">
                    <label className="block text-gray-800 font-medium">
                      address line 2:
                    </label>
                    <input
                      type="text"
                      name="address_line_2"
                      value={employeeData.address_line_2}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    />
                  </div>
                  <div className="md:col-span-2 lg:col-span-3">
                    <label className="block text-gray-800 font-medium">
                      nearby landmark:
                    </label>
                    <input
                      type="text"
                      name="nearby_landmark"
                      value={employeeData.nearby_landmark}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    />
                  </div>
                  <div className="md:col-span-2 lg:col-span-3">
                    <label className="block text-gray-800 font-medium">
                      pincode:
                    </label>
                    <input
                      type="text"
                      name="pincode"
                      value={employeeData.pincode}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    />
                  </div>
                  <div className="md:col-span-2 lg:col-span-3">
                    <label className="block text-gray-800 font-medium">
                      city:
                    </label>
                    <select
                      name="city_id"
                      value={employeeData.city_id}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    >
                      <option value="" disabled>
                        select city
                      </option>
                      {Array.isArray(cities) &&
                        cities.map((city) => (
                          <option key={city.id} value={city.id}>
                            {city.name}
                          </option>
                        ))}
                    </select>
                  </div>
                  <div className="md:col-span-2 lg:col-span-3">
                    <label className="block text-gray-800 font-medium">
                      email:
                    </label>
                    <input
                      type="email"
                      name="email"
                      value={employeeData.email}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    />
                  </div>
                </div>
                <div className="text-center mt-6">
                  <button
                    type="submit"
                    className="bg-#0e355b text-white px-4 py-2 rounded-md font-semibold"
                  >
                    create account
                  </button>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default AddEmployee;
