import React, { useState, useEffect } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronLeft } from '@fortawesome/free-solid-svg-icons';
import Sidebar from '../sidebar/Sidebar';
import axiosInstance from '../../api/axiosConfig';

const AddCustomer = () => {
  const navigate = useNavigate();
  const [customerData, setCustomerData] = useState({
    firstname: '',
    lastname: '',
    age: '',
    gender: '',
    email: '',
    address_line_1: '',
    address_line_2: '',
    nearby_landmark: '',
    pincode: '',
    city_id: '',
    mobile: '',
    image: null,
  });
  const [cities, setCities] = useState([]);
  const [imagePreview, setImagePreview] = useState(null);

  // Uncomment to fetch cities data from backend
  // useEffect(() => {
  //   const fetchCities = async () => {
  //     try {
  //       const response = await axiosInstance.get('/cities');
  //       if (Array.isArray(response.data)) {
  //         setCities(response.data);
  //       } else {
  //         console.error('Error: Data is not an array', response.data);
  //       }
  //     } catch (error) {
  //       console.error('Error fetching cities:', error.response || error.message);
  //     }
  //   };

  //   fetchCities();
  // }, []);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setCustomerData({
      ...customerData,
      [name]: value,
    });
  };

  const handleImageChange = (e) => {
    const file = e.target.files[0];
    if (file) {
      setCustomerData({
        ...customerData,
        image: file,
      });
      setImagePreview(URL.createObjectURL(file));
    }
  };

  const handleAddCustomerSubmit = async (e) => {
    e.preventDefault();
    const formData = new FormData();
    Object.keys(customerData).forEach((key) => {
      formData.append(key, customerData[key]);
    });

    try {
      await axiosInstance.post('http://localhost:5000/customers', formData, {
        headers: {
          'Content-Type': 'multipart/form-data',
        },
      });
      navigate('/customers');
    } catch (error) {
      console.error('Error adding customer:', error.response || error.message);
    }
  };

  return (
    <div className="flex flex-row">
      <Sidebar />
      <div className="w-full flex flex-col min-h-screen text-black">
        <div className="min-h-screen text-gray-800 p-6">
          <div className="flex justify-between items-center mb-6">
            <div className="flex items-center mb-6">
              <Link to="/customers" className="text-#0e355b text-xl mr-4">
                <FontAwesomeIcon icon={faChevronLeft} />
              </Link>
              <h1 className="text-2xl font-semibold text-#0e355b">
                add customer
              </h1>
            </div>
            <Link to="/CategoryList" className="text-blue-900">skip for now</Link>
          </div>
          <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
            <div className="space-y-6">
              <div className="text-center">
                <div className="inline-block relative">
                  <div className="bg-gray-300 w-24 h-24 rounded-full mx-auto overflow-hidden">
                    {imagePreview ? (
                      <img
                        src={imagePreview}
                        alt="Customer"
                        className="w-full h-full object-cover"
                      />
                    ) : (
                      <div className="w-full h-full flex items-center justify-center text-gray-500">
                        no image
                      </div>
                    )}
                  </div>
                  <input
                    type="file"
                    accept="image/*"
                    className="hidden"
                    id="imageUpload"
                    onChange={handleImageChange}
                  />
                  <button
                    type="button"
                    onClick={() => document.getElementById('imageUpload').click()}
                    className="absolute bottom-0 left-1/2 transform -translate-x-1/2 bg-gray-700 text-white text-xs px-2 py-1 rounded-full"
                  >
                    
                  </button>
                </div>
              </div>
              <div>
                <Link to="/add-customer">
                  <h2 className="text-lg font-semibold">customer information</h2>
                </Link>
                <Link to="/measurements">
                  <h2 className="text-lg font-semibold">measurements</h2>
                </Link>
              </div>
            </div>
            <div className="md:col-span-2 space-y-4">
              <form onSubmit={handleAddCustomerSubmit}>
                <div>
                  <label className="block text-gray-800 font-medium">
                    customer firstname:
                  </label>
                  <input
                    type="text"
                    name="firstname"
                    value={customerData.firstname}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">
                    customer lastname:
                  </label>
                  <input
                    type="text"
                    name="lastname"
                    value={customerData.lastname}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">
                    age:
                  </label>
                  <input
                    type="number"
                    name="age"
                    value={customerData.age}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                    <label className="block text-gray-800 font-medium">
                      gender:
                    </label>
                    <select
                      name="gender"
                      value={customerData.gender}
                      onChange={handleInputChange}
                      className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                    >
                      <option value="" disabled>
                        select gender
                      </option>
                      <option value="male">male</option>
                      <option value="female">female</option>
                      <option value="other">other</option>
                    </select>
                  </div>
                <div>
                  <label className="block text-gray-800 font-medium">
                    email:
                  </label>
                  <input
                    type="email"
                    name="email"
                    value={customerData.email}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">
                    address line 1:
                  </label>
                  <input
                    type="text"
                    name="address_line_1"
                    value={customerData.address_line_1}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">
                    address line 2:
                  </label>
                  <input
                    type="text"
                    name="address_line_2"
                    value={customerData.address_line_2}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">
                    nearby landmark:
                  </label>
                  <input
                    type="text"
                    name="nearby_landmark"
                    value={customerData.nearby_landmark}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">
                    pincode:
                  </label>
                  <input
                    type="text"
                    name="pincode"
                    value={customerData.pincode}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">
                    city:
                  </label>
                  <select
                    name="city_id"
                    value={customerData.city_id}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  >
                    <option value="" disabled>
                      select city
                    </option>
                    {Array.isArray(cities) &&
                      cities.map((city) => (
                        <option key={city.id} value={city.id}>
                          {city.name}
                        </option>
                      ))}
                  </select>
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">
                    mobile:
                  </label>
                  <input
                    type="tel"
                    name="mobile"
                    value={customerData.mobile}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div className="flex justify-end">
                  <button
                    type="submit"
                    className="bg-#0e355b text-white py-2 px-4 rounded-md"
                  >
                    add customer
                  </button>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default AddCustomer;
